@@ -1326,21 +1326,29 @@ GVWebPage::onPageTimeout ()
 }//GVWebPage::onPageTimeout
 
 void
-GVWebPage::onPageProgress(int /*progress*/)
+GVWebPage::onPageProgress(int progress)
 {
     pageTimeoutTimer.stop ();
-    qDebug("Page progressed. Not timing out!");
+    if (0 == progress) {
+        qDebug ("Page timeout timer started");
+    } else {
+        qDebug("Page progressed. Not timing out!");
+    }
     pageTimeoutTimer.setInterval (45 * 1000);
     pageTimeoutTimer.setSingleShot (true);
     pageTimeoutTimer.start ();
 }//GVWebPage::onPageProgress
 
 void
-GVWebPage::onSocketXfer (qint64 /*bytesXfer*/, qint64 /*bytesTotal*/)
+GVWebPage::onSocketXfer (qint64 bytesXfer, qint64 bytesTotal)
 {
     pageTimeoutTimer.stop ();
-    qDebug("Socket transferred data. Not timing out!");
-    pageTimeoutTimer.setInterval (15 * 1000);
+    if ((0 == bytesXfer) && (0 == bytesTotal)) {
+        qDebug("Started the timeout timer");
+    } else {
+        qDebug("Socket transferred data. Not timing out!");
+    }
+    pageTimeoutTimer.setInterval (20 * 1000);
     pageTimeoutTimer.setSingleShot (true);
     pageTimeoutTimer.start ();
 }//GVWebPage::onSocketXfer
